/*
 * DigiTool.h
 * 
 * Copyright (c) 2011, Digimetrie. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301  USA
 */

#ifndef  DIGITOOL_H
#define  DIGITOOL_H
//+++++++++++++++++++++++++++++++++++++++++++++++


//--------------------------------------------------------------------------
/**
\file Digitool.h
API commune aux cartes Digimtrie.
\n
\cond DOXY_DEBUG

\note modifications du	23/10/2001 : O.F.
\author stagiaire
\n
\n Modifications :
-# 07/08/2001: version originale (dernire modification)
-# 23/04/2003: Ajout de dfinition de nom de carte : PCI_MICROLAB
-# 30/04/2003: \#define _export _declspec(dllexport) remplac par
	\n \#define _export __declspec(dllexport) pour compatibilit avec Borland
-# Au 30/04/2003: Listes complte de tous les numros de carte
-# Au 14/05/2003: depart fichier O.F + ajout modification du stagiaire
-# + Ajout structure CF_CARTE + \#define trigger ananlogiques + modif Init_Conf
\n
\note modifications du	06/08/2003 :
-#  nouveau nom Digitoolusb.h pour gestion USB2 : 
-#  adaptation des define avec bit masq + elimination fonctions bas niveau pcilab
-#  mise  jour commentaires pour info client
\n
\note 03/12/2004 : ajout fonction set_id()
\note 10/05/2005 : ajout fonction Cread32()
\note 15/06/2006 : Ajout fonctions de bas niveau user gestion reseau USB_
\note 07/12/2006 : Ajout mise  jour define USB_TOR16 92 et define DT_TOR + USB_LAB_LP
\note 08_02_2007  : corrections numro d erreur
\note 11/04/2207  : ajout DT_AD_CPT
\note 26/11/2007  : Ajout parametre frequence dans fonction Ainfscan_buff()  
\note 04/11/2008 : version usblabr.dll modification version 1.0.0.0  VID + GUID  
\note 14/05/2009 : modification fonction get et set pleine echelle ad et da  
\note 17/12/2010 : Ajout de la X-macro DigiDefs_Cartes.def.h <-> D_CARTE_DIGI, et implmentation correspondante de Digi_GetCarte_Nom() et Digi_GetCarte_Dll()
                   Ajout de la X-macro DigiDefs_Errors.def.h <-> D_DIGI_ERR, et implmentation correspondante de Digi_GetErrorString()
                   Ajout de la X-macro DigiDefs_Events.def.h <-> D_DIGI_ERR, et implmentation correspondante de Digi_GetEventString()
\n

\note 14/04/2011 : Modification de la structure cf_Carte et de son utilisation :
	1 - Cette structure est cense dcrire les capacites fournies par un type de carte. 
		Elle ne doit donc tre initialis qu'une fois, et jamais chang.
	2 - Ajout du champ gain_max.

\note 14/04/2011 : Ajout de la fonction BOut()
\note 15/04/2011 : Ajout de la fonction BIn()   // un peu ambigue comme nom....
\note 28/04/2011 : ajout fonctions Capt_ReadEep() et Capt_WriteEep() + correction textes


\n IMPORTANT : Pour les dvelopeurs de Dlls Digimtrie, pour compiler il faudra un \#define DLL_CARTE_ID \<carte_ID\> o carte_ID est un identifiant de carte parmi ceux dans "DigiDefs_Cartes.def.h"
// Ex : passer au compilateur -D DLL_CARTE_ID=DIGI_ZIGBEE



\todo  vrifier la documentation des fonctions de l'API

\endcond */ // DOXY_DEBUG

//--------------------------------------------------------------------------



//--------------------------------------------------------------------------
/**
	\addtogroup API_group API de la Dll
	   Fonctions et structures de l'API de la Dll
	@{
*/
//--------------------------------------------------------------------------


//-----------------------------------------------
//-----------------------------------------------

#include <windows.h>


//||||||||||||||||||||||||||
//! \cond EXLUSION_OFF
//||||||||||||||||||||||||||

//--------------------------------------------------------------------------
// Macros Helpers pour les exportations des Dlls Digimtries
//--------------------------------------------------------------------------
#ifndef DOXYGEN
	#define _export __declspec(dllexport)
	#define Pascal __stdcall

	#define PROTO_DECL( _type )	\
		typedef _type

	// ********* C PLUS PLUS ONLY **********
	#if defined(__cplusplus) || defined(c_plusplus)
		#ifndef DEXPORT
			#define DEXPORT( _type  )	\
				_export					\
				_type					\
				PASCAL
		#endif

		// For C functions (somes in Digitool.c)
		#define C_DECL_START		extern "C" {
		#define C_DECL_END			}
		#define DTYPE_C( _type )	extern "C" _type


	// ************ C ONLY *************
	#else
		#ifndef DEXPORT
			#define DEXPORT( _type  )	\
				_export					\
				_type					\
				PASCAL
		#endif

		// For C functions (somes in Digitool.c)
		#define DTYPE_C( _type ) _type

		#define C_DECL_START
		#define C_DECL_END
	#endif

	// %%%%%%%%% WINDOWS ONLY %%%%%%%%%%%%%
	#if defined(_WINDOWS) || defined(WIN32)
		#define DIGI_CALLBACK_U PASCAL  CALLBACK
		#define DIGI_CALLBACK_T( _type ) _type
		#define DIGI_CALLBACK( _type ) DIGI_CALLBACK_T(_type) DIGI_CALLBACK_U
	#else
		#error DIGI_CALLBACK not defined for this system
	#endif



	//--------------------------------------------------------------------------------------
	// COMMON TYPES
	#ifndef uint
		#define uint unsigned int
	#endif
	#ifndef BYTE
		#define BYTE unsigned char
	#endif
	#ifndef WORD
		#define WORD unsigned short
	#endif
	#ifndef DWORD
		#define DWORD unsigned long
	#endif
	#ifndef DDWORD
		typedef  unsigned __int64 DDWORD;
	#endif

	#ifdef UNICODE
		#define P_STR	LPCWSTR
	#else
		#define P_STR	LPCSTR
	#endif

	#ifndef __cplusplus
		typedef unsigned short bool;
	#endif

	// Le compilateur peur crire sans les Dlls, les noms de fonctions prfix avec '_' ou '?' ou etc...
	// Cette macro dcale le pointeur char* DLL_F_NAME et sa taille associe DLL_F_NAME__LEN aprs l'ventuel prfixe
	#define UNPREFIXE_DLL_FCT_NAME( DLL_F_NAME, DLL_F_NAME__LEN )		\
		if( DLL_F_NAME[0] == '_' || DLL_F_NAME[0] == '?' )		\
		{														\
			DLL_F_NAME++;										\
			DLL_F_NAME__LEN--;									\
		}


// -------- version DOXYGEN des macros -----------
#else

	#define PROTO_DECL( _type ) typedef _type
	#define DEXPORT( _type ) _type
	#define DTYPE_C( _type ) _type
	#define DIGI_CALLBACK_U
	#define DIGI_CALLBACK_T( _type ) _type
	#define DIGI_CALLBACK( _type ) _type

	#define C_DECL_START
	#define C_DECL_END
#endif 






//|||||||||||||||||||||||||||||
/*! \endcond */ // EXLUSION_OFF
//|||||||||||||||||||||||||||||


//##########################################################################
/**
	\addtogroup Structs_group Structures utilss par la Dll
	   Ces structures sont passs ou rendu par certaines fonctions de la Dll
	@{
*/
//##########################################################################
//-------------------------------------
//		Types utiliss par la Dll
//-------------------------------------
// Structure utilise avec DigiView (Ainf, Aoutf, Ainfscan, Aoutfscan)

/****************** Def  Structure Carte **************************************/

enum E_TYPE_POLARITE
{
	POLARITE_MONO = 0,
	POLARITE_BIPO = 1,
};

enum TOR_PORT_CONFIGURABILITY
{
	TOR_IN,
	TOR_OUT,
	TOR_IN_OUT,
	TOR_IN_OUT_CO, //!< In/Out collecteur ouvert
};



typedef short TYPE_POLARITE;	//!< MONO=0, BIPO=1
#define  MAX_VOIES 32			//!< Limite haute du nombre de voies maximum pour une station

#pragma pack (2)  //alignement des 2 structures sur 2 octets copatible Digiview

//---------------------------------------------------------------------
//! Description de l'tat courant/voulu d'une carte digimtrie.
typedef struct CF_CARTE
{
 	short         		slot;       			 //!< numero de slot
    short         		no;         			 //!< numero de carte
	unsigned short		adresse;    			 //!< adresse carte  
	unsigned short		notpon;    				 //!< numero de tampon

 //***** DMA ****
    unsigned short	   	masq_canal,    			 //!< masque canal dma
    					n_dma,         			 //!< no dma
    					ad_dmal,       			 //!<  adresse dma low
    					ad_dmah;       			 //!<  adresse dma high

    unsigned char     page_rh1	//!< FIXDOC
					, ad_dmal1	//!< FIXDOC
					, ad_dmah1	//!< FIXDOC
					, page_rh2	//!< FIXDOC
					, ad_dmal2	//!< FIXDOC
					, ad_dmah2	//!< FIXDOC
					;

    short		        disk;	       			//!<  accs directe disque	 OUI/NON


 // *****  AD   
    short				  nvoies_ad;     			//!<  voie ad de dpart
    short 				  adnumsize;     			//!<  nombre de bits d'une acquisition analogique
    short 				  adnmaxvoies;   			//!<  max voies ad
    float                 adp_echelle;              //!<  pleine chelle ad
    short				  adpolarite[MAX_VOIES];    //!<  polarit ad (cf. enum E_TYPE_POLARITE)
    short                 addiff[MAX_VOIES];        //!<  voies diffrentielles
    

 //*****   DA

    short                 danmaxvoies;            //!<  nombre max de voies da
    float                 dap_echelle;            //!<  pleine chelle da
	short				  danumsize;              //!<  taille mot da
    short				  dapolarite[MAX_VOIES];  //!<  polarit da (cf. enum E_TYPE_POLARITE)
    short                 dadiff[MAX_VOIES];      //!<  voies diffrentielles


 //*****   TOR  
    USHORT				tormaxports,            //!<  nombre max de ports tor par composant (chaque port a 8 lignes [0|1] )
    					tormaxcomp;             //!<  nombre max de composants tor (pour compatibilite PIO-8255)
	short				torcomp;				//!<  INUTILSE PAR LA DLL

	//! Configurabilit des port TOR (cf. #TOR_PORT_CONFIGURABILITY)
	/** \note ici, pas de numro de composant :  chaque composant est assign une srie de 3 octets de la structure
	       qu'il ait ou pas 3 ports.
	    \note : au composants TOR numero Zero sont assignes les octets tconfig[0], tconfig[1] et tconfig[2]
	*/
    #define NB_MAX_TORS  10
    WORD				tconfig[NB_MAX_TORS];	

	USHORT				tEtat;					//!< A usage de DigiView (si bit  1 la ligne est en OUT)
	USHORT				tVal;					//!< A usage de DigiView a un sens seulement si la ligne est en OUT, le bit donne la valeur


 //****    TIM
    short				timmaxcomp;             //!<  nombre max de compteurs
    char            	nom[30];				//!< FIXDOC
    char				nom_dll[80];        	//!<  nom dll carte
	short		        no_ext;	       			//!<  n carte d'extension : CENSE Disparaitres avec le multi carte
	char		   		nom_ext[30];  			//!<  nom ext : CENSE Disparaitres avec le multi carte
    short 				reserved;    			
    short 				ext_voiecon;            //!<  extexsion voie connect avec carte ad
    short 				trigv_ad;				//!<  trigger ad voie
    short 				trigv_da;				//!<  trigger da voie
    short 				moyen;					//!< moyennage
    float				trig_ad;                //!< trig AD
    float				trig_da;                //!< trig DA
    short				t_trigger_ad;           //!< type trigger ad 0= dvalid 1=montant 2= descendant
	short				t_trigger_da;			//!< type trigger da 0= dvalid 1=montant 2= descendant
    short				f_buffer;               //!< flag mode buffer circulaire
    short				trigv_tor;              //!< reserv
    unsigned long		buffer_sz;              //!< taille buff circ
	short				priorite;				//!< protrit thread
    short				tgain;                  //!< type gain AD Binaire  ou Dcimal

    USHORT gain_max;							//!<  valeur maximum pour les paramtres gains

    short free_0;
    long				l8;                     //!< reserv
}
CF_CARTE;



//---------------------------------------------------------------------
//! Description de l'tat courant/voulu d'un capteur.
typedef struct CAPT
{
	short	status;		// enum TCONV version DLL
	short	t_conv;		// type conversion 
	short   carte;		// module
	short   voie;
	float	gain;
	float	decalage;   
	char	nom[16];  
	char	grandeur[16]; 
	char	unite1[16]; 
	float **flist;		// pointeur sur liste de flottants linearisation
	short		n;      // n elements de la liste de flottants
	short		type;   // type capt
	float	y1;			// point de mesure y1 servant  calculer les coefficients lineaires(pompiers
	float	y2;			// point de mesure y2 servant  calculer les coefficients lineaires(pompiers
} 
  CAPT  //!< FIXDOC
,*PCAPT //!< Pointeur sur #CAPT
;



#pragma pack ()


//##########################################################################
/*! @}*/ // Fin de Structs_group
//##########################################################################









//##########################################################################
/**
	\addtogroup Operationnal_group Fonctions controlant les cartes gres par la Dll
	   - Les fonctions d'acquisitions et positionnement : 
			-# analogiques ain...() aout...()
			-# digitales din...() dout...()

	   - Les fonctions d'initialisation et de reset des cartes.

	   - Les fonctions relatives aux capteurs.

	   - etc...
	@{
*/
//##########################################################################

//------------------------------------------------------------
//! Permet d'acceder  la configuration de la carte
/**
	pcf_carte doit pointer sur un zone mesurant au moins sizeof(CF_CARTE)
*/
//-----------
C_DECL_START
//-----------
DEXPORT(short)
Get_Conf( CF_CARTE* pcf_carte);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)			
(PASCAL *PROTO_Get_Conf)( CF_CARTE* pcf_carte);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_Conf	pf_Get_Conf;	
/*! \endcond */ // DOXY_DEBUG
//-----------
C_DECL_END



//-------------------------------------------
//! Configurer ou demander l'tat d'un capteur
/**
\param xpcapt : 
	-# si c'est une demande de l'tat d'une carte => la rponse sera stocke l.
	-# si c'est une requete de configuration => contient la configuration voulue pour ce capteur
\param flag : 
	-# si flag == FALSE => l'appelant veut connaitre la configuration du capteur
	-# si flag == TRUE  => l'appelant veut (re)configurer le capteur /warning Non impment
\return 0 si OK, sinon le code d'erreur
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(void)
Init_Capt(
			  CAPT *xpcapt
			, short flag		//Init_Capt
			);   


// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(void)
(PASCAL *PROTO_Init_Capt)(
					  CAPT *xpcapt
					, short flag		//Init_Capt
					);   

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Init_Capt	pf_Init_Capt;	
/*! \endcond */ // DOXY_DEBUG
//-----------
C_DECL_END


//-------------------------------------------
//! Reseter la carte
/**
	\param mode : FIXDOC
	\param exts : FIXDOC \warning ULONG dans PCILAB!!!
	\param carte :	FIXDOC 
	\param adresse :	FIXDOC
	\return 0 si OK, sinon le code d'erreur
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Reset_carte(   
			   USHORT mode
			 , USHORT exts
			 , USHORT carte
			 , USHORT adresse
			 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Reset_carte)(
			   USHORT mode
			 , USHORT exts
			 , USHORT carte
			 , USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Reset_carte	pf_Reset_carte;	
/*! \endcond */ // DOXY_DEBUG
//-----------
C_DECL_END


//-------------------------------------------
//! Paramtrage d'une voie d'une carte en mode Digital|Analogique, IN|OUT d'un port d'une carte
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dinit(		
			  USHORT portx        //!< numero du port A(0),B(1),C(2)...
			, USHORT mode         //!< configuration en entree ou sortie
			, USHORT no_composant //!< numero du groupe de port
			, USHORT carte        //!< Identifiant du type de carte
			, USHORT adresse      //!< adresse de base de la carte	
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
( PASCAL *PROTO_Dinit)(
			USHORT portx,        
			USHORT mode,         
			USHORT no_composant, 
			USHORT carte,        
			USHORT adresse       
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dinit	pf_Dinit;	
/*! \endcond */ // DOXY_DEBUG
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! Effectuer un et un seul chantillonage digital
/*
\warning la voie doit avoir t configurer en mode IN avec un appel prcdent  #Dinit()
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Din(		
			  USHORT *data			//!< pointeur de stockage de la donne lue 
			, USHORT portx			//!< numero du port A(0),B(1),C(2)...
			, USHORT no_composant	//!< numero du groupe de voie : FIXME prciser \<groupe de voie\>
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!< adresse de base de la carte	
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
( PASCAL *PROTO_Din)(
			  USHORT *data
			, USHORT portx
			, USHORT no_composant
			, USHORT carte
			, USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Din pf_Din;
/*! \endcond */ // DOXY_DEBUG
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Positionnement une sortie digital
/*
\warning le port doit avoir t configurer en mode OUT avec un appel prcdent  #Dinit()
\cond USBLAB

	\important Les ports de la gamme UsbLab sont en collecteur ouvert ET en logique ngative
		\n ie. criture d'une ligne du port  1 => la voie sera  0 en sortie

\endcond */ // USBLAB

//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dout(		
			  USHORT data         //!< valeur crite sur le port
			, USHORT portx        //!< numero du port A(0),B(1),C(2)...
			, USHORT no_composant //!< numero du groupe de port : FIXME prciser \<groupe de voie\>
			, USHORT carte        //!< Identifiant du type de carte
			, USHORT adresse       //!< adresse de base de la carte	
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Dout)(
			  USHORT data
			, USHORT portx
			, USHORT no_composant
			, USHORT carte
			, USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dout		pf_Dout;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Effectuer des chantillonages digitaux massifs et rguliers
/*
\warning le port doit avoir t configurer en mode IN avec un appel prcdent  #Dinit()
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dinscan(	
			  USHORT port_tampon  //!< premier port du tampon utilisateur 
			, USHORT port         //!< partir du port sur la carte  
			, USHORT n_ports_max  //!< Nombre maximum  de ports sur le tampon  utilisateur
			, USHORT n_ports      //!< acquisition sur n_ports
			, USHORT no_composant //!< numero du groupe de port (composant 0, 1,2 ou...)
			, ULONG  n_val         //!< nombre de echantillon  acquerir(tableau de donnees) 
			, ULONG  *frequence    //!< a la frequence de F (en Hertz) 
			, USHORT mode         //!< mode de configuration generateur interne
			, UCHAR  *tampon		  //!< tableau de donnees, zone de stockage
			, ULONG  ext           //!< extension, toujour a 0 
			, USHORT carte        //!< nom de la carte
			, USHORT adresse      //!< FIXDOC adresse de la carte
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Dinscan)(
				  USHORT port_tampon  
				, USHORT port         
				, USHORT n_ports_max  
				, USHORT n_ports      
				, USHORT no_composant 
				, ULONG  n_val         
				, ULONG  *frequence    
				, USHORT mode         
				, UCHAR  *tampon 
				, ULONG  ext           
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dinscan		pf_Dinscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Appliquer des positionnements digitaux rguliers sur une ou des voie  partir d'un tableau de valeurs
/*
\warning le port doit avoir t configurer en mode OUT avec un appel prcdent  #Dinit()
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Doutscan(	
			  USHORT port_tampon	//!< premier port du tampon utilisateur 
			, USHORT port			//!< partir du port sur la carte  
			, USHORT n_ports_max	//!< Nombre maximum  de ports sur le tampon  utilisateur
			, USHORT n_ports		//!< restitution sur n_ports
			, USHORT no_composant	//!< numero du groupe de port (composant 0, 12 ou...)
			, ULONG  n_val          //!< nombre de echantillon  acquerir(tableau de donnees) 
			, ULONG  *frequence     //!< a la frequence de F (en Hertz) 
			, USHORT mode			//!< mode de configuration generateur interne
			, UCHAR  *tampon		//!< tableau de donnees zone de stockage
			, ULONG  ext			//!< extension toujour a 0 
			, USHORT carte			//!< nom de la carte
			, USHORT adresse		//!< FIXDOC adresse de la carte
			);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Doutscan)(
				  USHORT port_tampon  
				, USHORT port         
				, USHORT n_ports_max  
				, USHORT n_ports      
				, USHORT no_composant 
				, ULONG  n_val         
				, ULONG  *frequence    
				, USHORT mode         
				, UCHAR  *tampon 
				, ULONG  ext           
				, USHORT carte        
				, USHORT adresse       
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Doutscan		pf_Doutscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Fixe l'tat d'une seule ligne d'un port Digital
/**
	Si bData == 0 alors la voie sera fix  l'tat bas, sinon  l'tat haut.
\cond USBLAB
		\important Les ports de la gamme UsbLab sont en collecteur ouvert ET en logique ngative
			\n ie. si "bData" == 1 => la voie sera  0 en sortie
\endcond */ // USBLAB

C_DECL_START
//-----------
DEXPORT(SHORT)
BOut(		
			  USHORT bData        //!< valeur crite sur le port 
			, USHORT num_ligne    //!< numero de la ligne (de 0  7)
			, USHORT portx        //!< numero du port A(0),B(1)C(2)...
			, USHORT no_composant //!< numero du groupe de port : FIXME prciser \<groupe de voie\>
			, USHORT carte        //!< Identifiant du type de carte
			, USHORT adresse      //!< adresse de base de la carte	
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_BOut)(
				  USHORT bData        
				, USHORT num_ligne    
				, USHORT portx        
				, USHORT no_composant 
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_BOut		pf_BOut;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
//! Lit l'tat d'une seule ligne d'un port Digital
DEXPORT(SHORT)
BIn(		
		  USHORT *data		  //!< pointeur de stockage de la donne lue 
		, USHORT num_ligne    //!< numero de la ligne (de 0  7)
		, USHORT portx        //!< numero du port A(0),B(1)C(2)...
		, USHORT no_composant //!< numero du groupe de port : FIXME prciser \<groupe de voie\>
		, USHORT carte        //!< Identifiant du type de carte
		, USHORT adresse      //!< adresse de base de la carte	
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_BIn)(
				  USHORT *data		  
				, USHORT num_ligne    
				, USHORT portx        
				, USHORT no_composant 
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_BIn		pf_BIn;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//---------------------------------------------------------------------------------------
//! Effectuer un et un seul chantillonage analogique
/*
\warning le port doit avoir t configur en mode OUT analogique avec un appel prcdent  #Dinit()
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ain(
	  USHORT *data  //!< rsultat en binaire de la conversion 
	, USHORT voie        //!< voie analogique slectionne
	, USHORT gain        //!< valeur du gain (voir selon la carte)
	, USHORT mode        //!< selection niveau et configuration d'entree (voir selon la carte)
	, ULONG  exts         //!< extension toujour a 0
	, USHORT carte       //!< Identifiant du type de carte
	, USHORT adresse     //!< FIXDOC adresse de la carte
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(__stdcall  *PROTO_Ain)(
					  USHORT *data  
					, USHORT voie        
					, USHORT gain        
					, USHORT mode        
					, ULONG  exts         
					, USHORT carte       
					, USHORT adresse     
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ain		pf_Ain;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(short)
Ainv(
		  WORD  *tampon   //!< Segment du tableau de donnes
		, WORD  voie           //!< Acquisition a partir de la voie V sur la carte
		, WORD  n_voies        //!< Nombre de voies a acquerir sur la carte  
		, WORD  gain[]    //!< Configuration du gain pour chaque voie Gain[nb_voies](voir selon la carte)
		, WORD  mode           //!< mode de configuration generateur interne + dclenchement 
		, ULONG exts          //!< extension toujour a 0
		, WORD  carte          //!< Identifiant du type de carte
		, WORD  adresse		  //!< FIXDOC adresse de la carte
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainv)(
				  WORD  *tampon   
				, WORD  voie           
				, WORD  n_voies        
				, WORD  gain[]    
				, WORD  mode           
				, ULONG exts          
				, WORD  carte          
				, WORD  adresse		  
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainv	pf_Ainv;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainf(
		  float *fdata		 //!< rsultat en tension de la conversion 
		, USHORT voie        //!< voie analogique slectionne
		, USHORT gain        //!< valeur du gain (voir selon la carte)
		, USHORT mode        //!< selection niveau et configuration d'entree (voir selon la carte)
		, ULONG exts         //!< extension toujour a 0
		, USHORT carte       //!< Identifiant du type de carte
		, USHORT adresse     //!< FIXDOC adresse de la carte
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainf)(
				  float *fdata		 
				, USHORT voie        
				, USHORT gain        
				, USHORT mode        
				, ULONG exts         
				, USHORT carte       
				, USHORT adresse     
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainf	pf_Ainf;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainfv(
		  FLOAT *tampon		  //!<  Segment du tableau de donnes
		, WORD  voie           //!<  Acquisition a partir de la voie V sur la carte
		, WORD  n_voies        //!<  Nombre de voies a acquerir sur la carte  
		, WORD  gain[]    //!<  Configuration du gain pour chaque voie Gain[nb_voies](voir selon la carte)
		, WORD  mode           //!<  mode de configuration generateur interne + dclenchement 
		, ULONG exts          //!<  extension toujour a 0
		, WORD  carte          //!<  nom ou numero de la carte
		, WORD  adresse        //!<  adresse de la carte
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainfv)(
				  FLOAT *tampon		  
				, WORD  voie           
				, WORD  n_voies        
				, WORD  gain[]    
				, WORD  mode           
				, ULONG exts          
				, WORD  carte          
				, WORD  adresse        
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfv	pf_Ainfv;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END

    
//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainscan(
			  USHORT voie_tampon	//!<  Stockage a partir de la premiere voie du tampon utilisateur	      
			, USHORT voie			//!<  Acquisition a partir de la voie V sur la carte	      
			, USHORT n_voies_max	//!<  Nombre de voies maximum sur le tampon utilisateur     
			, USHORT n_voies		//!<  Nombre de voies a acquerir sur la carte     
			, USHORT gain[]			//!<  Configuration du gain pour chaque voie Gain[nb_voies](voir selon la carte)	 
			, ULONG  n_val			//!<  nombre d'echantillons  acquerir(tableau de donnees)     
			, ULONG  *frequence		//!<   la frquence (en Hertz)   
			, USHORT mode			//!<  mode de configuration generateur interne + dclenchement 
			, USHORT *tampon		//!<  tableau de donnees binaires zone de stockage 
			, ULONG  exts			//!<  extension, toujour a 0 (sauf pour la gamme usb ou ext dfini la priorit du thread d'acqu (0  3) )
			, USHORT carte 			//!<  nom de la carte		      
			, USHORT adresse		//!<  adresse de la carte		      
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainscan)(
					  USHORT voie_tampon	
					, USHORT voie			
					, USHORT n_voies_max	
					, USHORT n_voies		
					, USHORT gain[]			
					, ULONG  n_val			
					, ULONG  *frequence		
					, USHORT mode			
					, USHORT *tampon		
					, ULONG  exts			
					, USHORT carte 			
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainscan		pf_Ainscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! AINSCAN_BUFF: lecture buffer circulaire ainscan asynchrone	  */
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Ainscan_buff(
				  WORD		*Buffer		//!<  pointeur sur le buffer de lecture utilisateur
				, ULONG		*nb_val		//!<  nombre de valeur 16 bits  lire (test max 32768) 6> retour octet lu effectif  
				, WORD		*stop		//!<  etat de l'acquisition thread 1=en cour 0=stoppee
				, ULONG		timeout		/*!< -# Si 0 => Attente infinie jusqu'a ce que nb_val ait t rcupre
											 -# Si INFINITE => Retour immdiat avec ce qui est prsent dans le buffer avec nb_val maximum
											 -# Sinon =< Retourne quand nb_val sont rcupr OU que timeout seconde se sont couls.
										*/
				, WORD		carte 		//!< nom de la carte		      
				, WORD		adresse		//!< FIXDOC adresse de la carte		      
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainscan_buff)(
				  WORD		*Buffer		
				, ULONG		*nb_val		
				, WORD		*stop		
				, ULONG		timeout		
				, WORD		carte 		
				, WORD		adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainscan_buff		pf_Ainscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainfscan(
			  USHORT voie_tampon	//!<  Stockage a partir de la premiere voie du tampon utilisateur	      
			, USHORT voie			//!<  Acquisition a partir de la voie V sur la carte	      
			, USHORT n_voies_max	//!<  Nombre de voies maximum sur le tampon utilisateur     
			, USHORT n_voies		//!<  Nombre de voies a acquerir sur la carte     
			, USHORT gain[16]		//!<  Configuration du gain pour chaque voie Gain[nb_voies](voir selon la carte)	 
			, ULONG  n_val			//!<  nombre d'echantillons  acquerir(tableau de donnees)     
			, ULONG  *frequence		//!<   la frquence (en Hertz)   
			, USHORT mode			//!<  mode de configuration generateur interne + dclenchement  (cf. les macros DT_AD_...)
			, float  *tampon			//!<  tableau de donnees tension zone de stockage 
			, ULONG  exts			//!<  extension toujour a 0  FIXME : pour les usb ici c'est la priorit du thread d'acquisition
			, USHORT carte 			//!<  nom de la carte		      
			, USHORT adresse		//!<  adresse de la carte		      
		);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainfscan)(
				  USHORT voie_tampon	
				, USHORT voie			
				, USHORT n_voies_max	
				, USHORT n_voies		
				, USHORT gain[16]		
				, ULONG  n_val			
				, ULONG  *frequence		
				, USHORT mode			
				, float  *tampon		
				, ULONG  exts			
				, USHORT carte 			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfscan		pf_Ainfscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Ainfscan_buff( 
				  WORD	voie		//!<  partir de la voie V de la carte	      
				, WORD	n_voies		//!< Nombre de voies  acquerrir      
				, WORD	gain[]		//!< avec le gain G[tableau_gain]	 
				, float *Buffer		//!< pointeur sur le buffer de lecture utilisateur
				, ULONG *nb_val		//!< nombre de valeur 16 bits  lire (test max 32768) -> retour octet lu effectif 
									//   ATTENTION: multiple du nombre de voies  acquerir
				, ULONG *frequence  //!< frequence dfinie dans la fonction Ainfscan() pour slection incrment auto 
				, WORD	*_stop		//!< etat de l'acquisition thread 1=en cour 0=stoppee
				, ULONG timeout		/*!<  -# Si 0 => Attente infinie jusqu'a ce que nb_val ait t rcupre
										  -# Si INFINITE => Retour immdiat avec ce qui est prsent dans le buffer avec nb_val maximum
										  -# Sinon =< Retourne quand nb_val sont rcupr OU que timeout seconde se sont couls.
									*/
				, WORD  carte 		//!< nom de la carte		      
				, WORD  adresse		//!< FIXDOC adresse de la carte		     
		);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainfscan_buff)(
				  WORD	voie		
				, WORD	n_voies		
				, WORD	gain[]		
				, float *Buffer		
				, ULONG *nb_val		
									
				, ULONG *frequence  
				, WORD	*_stop		
				, ULONG timeout		/*!<  -# Si 0 => Attente infinie jusqu'a ce que nb_val ait t rcupre
										  -# Si INFINITE => Retour immdiat avec ce qui est prsent dans le buffer avec nb_val maximum
										  -# Sinon =< Retourne quand nb_val sont rcupr OU que timeout seconde se sont couls.
									*/
				, WORD  carte 		
				, WORD  adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfscan_buff		pf_Ainfscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aout(
		   USHORT data       //!< Valeur en binaire  crire 
		 , USHORT voie       //!< voie de sortie analogique slectionne
		 , USHORT mode       //!< selection niveau et configuration de sortie(voir selon la carte)
		 , ULONG exts        //!< extension toujour a 0
		 , USHORT carte      //!< Identifiant du type de carte
		 , USHORT adresse    //!< FIXDOC adresse de la carte
	 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aout)(
				   USHORT data       
				 , USHORT voie       
				 , USHORT mode       
				 , ULONG exts        
				 , USHORT carte      
				 , USHORT adresse    
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aout		pf_Aout;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aoutf(
		   float data       //!< Valeur en tension  crire 
		 , USHORT voie      //!< voie de sortie analogique slectionne
		 , USHORT mode      //!< selection niveau et configuration de sortie(voir selon la carte)
		 , ULONG exts       //!< extension toujour a 0
		 , USHORT carte     //!< Identifiant du type de carte
		 , USHORT adresse	//!< FIXDOC adresse de la carte
	 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutf)(
				   float data       
				 , USHORT voie      
				 , USHORT mode      
				 , ULONG exts       
				 , USHORT carte     
				 , USHORT adresse	
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutf		pf_Aoutf;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aoutscan(					
			  USHORT voie_tampon	//!<  lecture a partir de la premiere voie du tampon utilisateur	
			, USHORT voie_da        //!<  restitution a partir de la voie V sur la carte
			, USHORT n_voies_max	//!<  Nombre de voies maximum sur le tampon utilisateur
			, USHORT n_voies_da     //!<  restitution sur N voies sur la carte
			, ULONG n_val	  		//!<  nombre d'echantillons  restituer(tableau de donnees)
			, ULONG *frequence	  	//!<   la frquence (en Hertz)
			, USHORT tint       	//!<  toujours a 0
			, USHORT mode			//!<  mode de configuration generateur interne + dclenchement  (cf. les macros DT_AD_...)
			, USHORT polarite[] 	//!<  INUTILISE
			, USHORT *tampon		//!<  tableau de donnees binaires zone de stockage
			, ULONG ext             //!<  extension toujour a 0 
			, USHORT carte 	 		//!<  nom de la carte
			, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutscan)(
					  USHORT voie_tampon	
					, USHORT voie_da        
					, USHORT n_voies_max	
					, USHORT n_voies_da     
					, ULONG n_val	  		
					, ULONG *frequence	  	
					, USHORT tint       	
					, USHORT mode			
					, USHORT polarite[] 	
					, USHORT *tampon		
					, ULONG ext             
					, USHORT carte 	 		
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutscan		pf_Aoutscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
//-----------
C_DECL_START
DEXPORT(SHORT)
Aoutfscan(				
			  USHORT voie_tampon	//!<  lecture a partir de la premiere voie du tampon utilisateur	
			, USHORT voie_da        //!<  restitution a partir de la voie V sur la carte
			, USHORT n_voies_max	//!<  Nombre de voies maximum sur le tampon utilisateur
			, USHORT n_voies_da     //!<  restitution sur N voies sur la carte
			, ULONG n_val	  		//!<  nombre d'echantillons  restituer(tableau de donnees)
			, ULONG *frequence	  	//!<   la frquence (en Hertz)
			, USHORT tint       	//!<  toujours a 0
			, USHORT mode			//!<  mode de configuration generateur interne + dclenchement  (cf. les macros DT_AD_...)
			, USHORT polarite[] 	//!<  Configuration de la polarite pour chaque voie (voir selon la carte)
			, float *tampon			//!<  tableau de donnees tension zone de stockage
			, ULONG ext				//!<  extension toujour a 0 
			, USHORT carte 	 		//!<  nom de la carte
			, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutfscan)(
					  USHORT voie_tampon	
					, USHORT voie_da        
					, USHORT n_voies_max	
					, USHORT n_voies_da     
					, ULONG n_val	  		
					, ULONG *frequence	  	
					, USHORT tint       	
					, USHORT mode			
					, USHORT polarite[] 	
					, float *tampon			
					, ULONG ext				
					, USHORT carte 	 		
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutfscan		pf_Aoutfscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


////////////////////////////////////////////////
//		Gnrateur et compteur 
////////////////////////////////

//---------------------------------------------------------------------------------------
//! Initialise le gnrateur
// FIXME : qu'est ce qu'un gnrateur
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ginit(		
		  ULONG  *frequence		//!<  frquence du gnrateur
		, USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte          //!< Identifiant du type de carte
		, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ginit)(
				  ULONG  *frequence		
				, USHORT no_composant	
				, USHORT mode			
				, USHORT carte          
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ginit		pf_Ginit;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! Valide la Gate (programmable) du compteur  pour dmarrer le gnrateur
// FIXME : qu'est ce qu'un gnrateur
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Gstart(
			  USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Gstart)(
				  USHORT no_composant	
				, USHORT mode			
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gstart		pf_Gstart;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! Stoppe le gnrateur par la Gate ou par criture
// FIXME : qu'est ce qu'un gnrateur ? Qu'est ce que la Gate ?
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Gstop(	
		  USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode           //!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte          //!< Identifiant du type de carte
		, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Gstop)(
				  USHORT no_composant	
				, USHORT mode           
				, USHORT carte          
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gstop		pf_Gstop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! Initialise le compteur (FIXME : le compteur du gnrateur ?)
C_DECL_START
//-----------
DEXPORT(SHORT)
Cinit(			
		  USHORT valeur			//!<  valeur de dpart du compteur
		, USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte			//!< Identifiant du type de carte
		, USHORT adresse		//!<  adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cinit)(
				  USHORT valeur			
				, USHORT no_composant	
				, USHORT mode			
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cinit		pf_Cinit;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Valide la Gate du compteur pour dmarrer le comptage (FIXME : le compteur du gnrateur ?)
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cstart(			
			  USHORT no_composant	//!< voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!< FIXDOC adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cstart)(
				  USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cstart		pf_Cstart;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Stoppe le compteur par la Gate ou par criture (FIXME : le compteur du gnrateur ? Qu'est ce que la Gate ? )
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cstop(		
			  USHORT no_composant	//!< voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!< FIXDOC adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cstop)(
				  USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cstop		pf_Cstop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Permet de lire le compteur (FIXME : le compteur du gnrateur ?)
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cread(		
			  USHORT *data			//!< valeur lue sur le compteur
			, USHORT no_composant	//!< voir Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!< FIXDOC adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cread)(
				  USHORT *data			
				, USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cread		pf_Cread;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Permet de lire le compteur (FIXME : le compteur du gnrateur ?)
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cread32(		
			  DWORD *data			//!< valeur lue sur le compteur 32 bits unsigned long
			, USHORT no_composant	//!< voir Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< Identifiant du type de carte
			, USHORT adresse		//!< FIXDOC adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cread32)(
				  DWORD *data			
				, USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cread32		pf_Cread32;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Gs_init(
			  WORD voie_da              //!< voie de sortie ananlogique
			, WORD mode                 //!< mode de generation mode=sinus / mono ou bipolaire
			, WORD horloge              //!< horloge utilise par la carte en MHZ 1=2MHz,2=4MHZ,3=10MHz4=25MHz
			, WORD phase                //!< dcalage de phase en degr de 1  360
			, ULONG *frequence			//!< de 1 Hz  1KHz generation logicielle
			, ULONG exts		        //!< extension future 
			, WORD carte				//!< Identifiant du type de carte
			, WORD adresse				//!< FIXDOC adresse de la carte
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Gs_init)(
				  WORD voie_da              
				, WORD mode                 
				, WORD horloge             
				, WORD phase                
				, ULONG *frequence			
				, ULONG exts		        
				, WORD carte				
				, WORD adresse				
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gs_init		pf_Gs_init;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Gs_stop(
			  WORD voie_da		//!< numro de la voie da a arreter
			, ULONG exts		//!< extension future 
			, WORD carte		//!< Identifiant du type de carte
			, WORD adresse		//!< FIXDOC adresse de la carte
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Gs_stop)(
					  WORD voie_da		
					, ULONG exts		
					, WORD carte		
					, WORD adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gs_stop		pf_Gs_stop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




/////////////////////////////////////////////////////
//		IO analogique + logique et compteur
/////////////////////////////////////////////////////

//---------------------------------------------------------------------------------------
//! Conversion analogique + numrique + timer multi voie dans tampon
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multiscan(
			  WORD  voie_tampon		//!<   partir de la voie du tampon      
			, WORD  voie			//!<   partir de la voie V de la carte  
			, WORD  n_voies_max		//!<  Nombre de voies max en tampon      
			, WORD  n_voies			//!<  Nombre de voies AD a acquerrir  + 2= short port din + short timer1 
			, WORD  gain[]			//!<  avec le gain G[tableau_gain]	      
			, ULONG n_val			//!<  sur N val (tableau de donnes)    
			, ULONG *frequence		//!<   la frquence (en Hertz)      
			, WORD  mode			//!<  voir Define DT_AD_XXXX             
			, WORD  *tampon			//!<  segment du tableau de donnes      
			, ULONG exts			//!<  extension                          
			, WORD  carte 			//!< Identifiant du type de carte	      
			, WORD  adresse			//!< FIXDOC adresse de la carte      
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multiscan)(
					  WORD  voie_tampon		
					, WORD  voie			
					, WORD  n_voies_max		
					, WORD  n_voies			
					, WORD  gain[]			
					, ULONG n_val			
					, ULONG *frequence		
					, WORD  mode			
					, WORD  *tampon			
					, ULONG exts			
					, WORD  carte 			
					, WORD  adresse			
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multiscan		pf_Multiscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! lecture buffer circulaire multiscan asynchrone
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multiscan_buff(
				  WORD  *Buffer		//!< pointeur sur le buffer de lecture utilisateur
				, ULONG *nb_val		//!< nombre de valeur 16 bits  lire (test max 32768) -> retour octet lu effectif 
				, WORD  *stop		//!< etat de l'acquisition thread 1=en cour 0=stoppee
				, ULONG timeout		/*!< -# Si 0 => Attente infinie jusqu'a ce que nb_val ait t rcupre
											 -# Si INFINITE => Retour immdiat avec ce qui est prsent dans le buffer avec nb_val maximum
											 -# Sinon =< Retourne quand nb_val sont rcupr OU que timeout seconde se sont couls.
									*/
				, WORD  carte 		//!< Identifiant du type de carte      
				, WORD	adresse		//!< FIXDOC adresse de la carte	         
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multiscan_buff)(
						  WORD  *Buffer		
						, ULONG *nb_val		
						, WORD  *stop		
						, ULONG timeout		
						, WORD  carte 		
						, WORD	adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multiscan_buff		pf_Multiscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Conversion analogique + numrique multi voie dans tampon valuers flottantes
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multifscan(
			  WORD  voie_tampon		//!<   partir de la voie du tampon      
			, WORD  voie			//!<   partir de la voie V de la carte  
			, WORD  n_voies_max		//!<  Nombre de voies max en tampon      
			, WORD  n_voies			//!<  Nombre de voies AD a acquerrir  + 2= short port din + short timer1 
			, WORD  gain[]			//!<  avec le gain G[tableau_gain]	      
			, ULONG n_val			//!<  sur N val (tableau de donnes)    
			, ULONG *frequence		//!<   la frquence (en Hertz)      
			, WORD  mode			//!<  voir Define DT_AD_XXXX             
			, float  *tampon			//!<  segment du tableau de donnes      
			, ULONG exts			//!<  extension                          
			, WORD  carte 			//!< Identifiant du type de carte	      
			, WORD  adresse			//!< FIXDOC adresse de la carte      
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multifscan)(
					  WORD  voie_tampon		
					, WORD  voie			
					, WORD  n_voies_max		
					, WORD  n_voies			
					, WORD  gain[]			
					, ULONG n_val			
					, ULONG *frequence		
					, WORD  mode			
					, float  *tampon			
					, ULONG exts			
					, WORD  carte 			
					, WORD  adresse			
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multifscan		pf_Multifscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! lecture buffer circulaire multiscan asynchrone en valeurs flottantes
/**
  Important: dpart toujours sur canal0 (quivalent param premiere voie=0)

  \return 
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multifscan_buff(
				  WORD voie        //!< numro de la premiere voie ou canal : IMPORTANT  toujours 0 
				, WORD n_voies      //!< Nombre de voies totale AD+tor  acquerrir 
				, WORD  gain[]		//!< Pointeur sur le tableau de gain G[tableau_gain]qui inclus gain+voie+mode+tor 
				, float  *Buffer	//!< pointeur sur le buffer de lecture utilisateur en valeur flottantes
				, ULONG *nb_val		//!< nombre de valeur 16 bits  lire (test max 32768) -> retour octet lu effectif 
				, ULONG	*frequence  //!< frequence dfinie dans la fonction Ainfscan() laisse pour test limites seulement
				, WORD  *stop		//!< etat de l'acquisition thread 1=en cour 0=stoppee
				, ULONG timeout		/*!< -# Si 0 => Attente infinie jusqu'a ce que nb_val ait t rcupre
											 -# Si INFINITE => Retour immdiat avec ce qui est prsent dans le buffer avec nb_val maximum
											 -# Sinon =< Retourne quand nb_val sont rcupr OU que timeout seconde se sont couls.
									*/
				, WORD  carte 		//!< Identifiant du type de carte      
				, WORD	adresse		//!< FIXDOC adresse de la carte	         
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multifscan_buff)(
						  WORD voie         	
						, WORD n_voies      
						, WORD  gain[]		
						, float  *Buffer	
						, ULONG *nb_val	
						, ULONG	*frequence 
						, WORD  *stop		
						, ULONG timeout		
						, WORD  carte 		
						, WORD	adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multifscan_buff		pf_Multifscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! permet de lire le nombre d'echantillons disponible dans le buffer
/**
circulaire interne : utilise par les fonctions scan()     asynchrone + l' etat du thread d'acquisition     
*/  
//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(short)
Test_buff(
			  ULONG		*ech_disponible	//!< nombre de valeur 16 bits  lire disponible dans le buffer virculaire interne
			, WORD		*stop			//!< etat de l'acquisition thread 0=en cour 1=stoppee
			, ULONG     exts			//!< extension                        
			, WORD      carte 			//!< FIXDOC nom de la carte		     
			, WORD		adresse			//!< FIXDOC adresse de la carte
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Test_buff)(
						  ULONG		*ech_disponible	
						, WORD		*stop			
						, ULONG     exts			
						, WORD      carte 			
						, WORD		adresse			
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Test_buff		pf_Test_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! ecriture dans le potentiometre
/**
Ecrire commande et valeur dans le potentiometre numerique
de rglage gain et offset du convertisseur A/N                         
\warning USBLABR uniquement
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Write_Pot(
                  USHORT data		//!< valeur a ecrire
                , USHORT cde		//!< commande et adresse
				, USHORT ext		//!< Extension future
				, USHORT carte		//!< FIXDOC Nom de la carte (cf. les \#define )
                , USHORT adresse	//!< FIXDOC Adresse de la carte
          );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Write_Pot)(
						  USHORT data		
						, USHORT cde		
						, USHORT ext		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Write_Pot		pf_Write_Pot;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Lecture potentiomtre
/**
Lecture valeur position ou mmoire EEPROM dans le       
potentiometre numerique du rglage gain et offset du convertisseur A/N 
pour lecture => 
	-# USB_Write_pot Cde 9 ou 10 
	-# puis USB_Read_Pot Cde0 NOP pour lecture sur SDO
\note Cde 9 lecture memoire EEMEN(ADDR) et 10 lecture valeur 8 bits RDAC(A0)
      \n	ADDR=2=USR1  15=USR14                   A0=0=RDAC1 et 1=RDAC2
\warning USBLABR uniquement
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Read_Pot(
              USHORT *result		//!< valeur lue
            , USHORT cde			//!< commande et adresse //!< non utilis = NOP par defaut
			, USHORT ext			//!< Extension future
			, USHORT carte			//!< FIXDOC Nom de la carte (cf. les \#define )
            , USHORT adresse		//!< FIXDOC Adresse de la carte
          );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Read_Pot)(
						  USHORT *result		
						, USHORT cde			
						, USHORT ext			
						, USHORT carte			
						, USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Read_Pot		pf_Read_Pot;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Calibrage du module AN
/** Cette fonction effectue un calibrage du module AN,
avec le rglage du gain et de l'offset du convertisseur A/N 
*/
C_DECL_START
//-----------
DEXPORT(short)
Calibrage_An(
                  USHORT cde        //!< cde=operation a effectuer 
                , USHORT action		//!< fonctions  raliser
				, USHORT voie_ref	//!< voie connecte  la tension de calibrage: rglage pleine chelle GAIN
                , USHORT voie_gnd	//!< voie connecte au 0 volt de rfrence AGND : rglage du 0 OFFSET
                , float  ref_volts	//!< tension de rfrence pour le calibrage
				, USHORT carte		//!< FIXDOC Nom de la carte (cf. les \#define )
                , USHORT adresse	//!< FIXDOC Adresse de la carte
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Calibrage_An)(
						  USHORT cde        
						, USHORT action		
						, USHORT voie_ref	
						, USHORT voie_gnd	
						, float  ref_volts	
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Calibrage_An		pf_Calibrage_An;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



/////////////////////////////////////////////////////
//		IO bas-niveau
///////////////////////

//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Tst_trigger( 
				  USHORT mode		//!< voir mode de declenchement Define DT_AD_TRGxx (selon carte)
				, USHORT carte		//!< Identifiant du type de carte
				, USHORT adresse	//!< FIXDOC Adresse de la carte
			 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Tst_trigger)(
						  USHORT mode		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Tst_trigger		pf_Tst_trigger;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Lecture du numro id (identifier) de la station switch interne  8 positions
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Get_id(
			  USHORT *deviceID			//!< FIXDOC
			, USHORT ext				//!< Extension future
			, USHORT carte				//!< Nom de la carte (cf. les \#define )
			, USHORT adresse			//!< FIXDOC Adresse de la carte
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_id)(
					  USHORT *deviceID		
					, USHORT ext				
					, USHORT carte				
					, USHORT adresse			
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_id		pf_Get_id;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! ecriture du numro id (identifier) de la station eeprom interne sur 8 bits
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Set_id(
		      USHORT deviceID	//!< id de la station sur 8 bits valides 0  128
			, USHORT ext		//!< Extension future
			, USHORT carte		//!< Nom de la carte (cf. les \#define )
            , USHORT adresse	//!< FIXDOC Adresse de la carte
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Set_id)(
					  USHORT deviceID	
					, USHORT ext		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Set_id		pf_Set_id;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! User_WriteEep : ecriture eeprom mot de 16 bits  dans la zone utilisateur*/
/**
   Zone fixe alloue de 64 mots de 16 bits ( rserve sur la station de $3100  317F =128 octets)
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2 
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
User_WriteEep(
				    USHORT data		//!< Valeur du mot de 16 bits a ecrire
				  , USHORT adrmem	//!< Adresse memoire de stockage: 0  63
				  , USHORT ext		//!< Extension future
				  , USHORT carte	//!< Nom de la carte (cf. les \#define )
				  , USHORT adresse	//!< FIXDOC Adresse de la carte
			  );	

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_User_WriteEep)(
						USHORT data		
					  , USHORT adrmem	
					  , USHORT ext		
					  , USHORT carte	
					  , USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_User_WriteEep		pf_User_WriteEep;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! User_ReadEep : lecture eeprom mot de 16 bits  dans la zone utilisateur
/**
   Zone fixe alloue de 64 mots de 16 bits ( rserve sur la station de $3100  317F =128 octets)
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
User_ReadEep(
				  USHORT *data		//!< Valeur du mot de 16 bits lue
				, USHORT adrmem		//!< Adresse memoire de lecture: 0  63
				, USHORT ext		//!< Extension future
				, USHORT carte		//!< Nom de la carte (cf. les \#define )
				, USHORT adresse	//!< FIXDOC Adresse de la carte
			);	

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_User_ReadEep)(
						  USHORT *data		
						, USHORT adrmem		
						, USHORT ext		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_User_ReadEep		pf_User_ReadEep;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Capt_WriteEep : ecriture dans la mmoire eeprom i2c capteur
/**
   Utilisation de la memoire i2c de 2K bits = 256 octets disponible sur chaque capteur.
   info: adresse du capteur0 = 0  FF capteur0 = 100  1FF et capteur0 = 200 2FF
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2
*/
C_DECL_START
//-----------
DEXPORT(short)
Capt_WriteEep(
				    USHORT data			//!<  valeur du mot de 16 bits a ecrire
				  , USHORT adrmem		//!<  adresse memoire de 0  127
				  , USHORT nr_capteur	//!< numro du capteur de 0  7
				  , USHORT ext			//!<  Extension future
				  , USHORT carte		//!<  Nom de la carte (Voir \#define)
				  , USHORT adresse		//!<  Adresse de la carte
			  );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Capt_WriteEep)(
							USHORT data			
						  , USHORT adrmem		
						  , USHORT nr_capteur	
						  , USHORT ext			
						  , USHORT carte		
						  , USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Capt_WriteEep		pf_Capt_WriteEep;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Capt_ReadEep : Lecture dans la mmoire eeprom i2c capteur
/**
   Utilisation de la memoire i2c de 2K bits = 256 octets disponible sur chaque capteur.
   info: adresse du capteur0 = 0  FF capteur0 = 100  1FF et capteur0 = 200 2FF
   Lecture par mots de 16 bits => adresse de 0  63 => adrmem x2
*/
C_DECL_START
//-----------
DEXPORT(short)
Capt_ReadEep(
				   USHORT *data			//!< valeur de mots de 16 bits lu
				 , USHORT adrmem		//!< adresse memoire de 0  127
				 , USHORT nr_capteur	//!< numro du capteur de 0  7
				 , USHORT ext			//!< Extension future
				 , USHORT carte			//!< Nom de la carte (Voir \#define)
				 , USHORT adresse		//!< Adresse de la carte
			 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Capt_ReadEep)(
						   USHORT *data			
						 , USHORT adrmem		
						 , USHORT nr_capteur	
						 , USHORT ext			
						 , USHORT carte			
						 , USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Capt_ReadEep		pf_Capt_ReadEep;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Lecture du nombre de stations trouvees, lecture du numro id et du nom symbolique
// FIXME : cette fonction retourne ou prend un char* en paramtre, est-ce bien scure ?
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Get_devices(
				  USHORT *nbstations	//!< nombre de stations detectees
				, char   *devicenom		//!< pointeur sur Nom symbolique du device
                , USHORT *deviceID		//!< FIXDOC
				, USHORT carte			//!< Nom de la carte (cf. les \#define )
                , USHORT adresse		//!< FIXDOC Adresse de la carte
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_devices)(
						  USHORT *nbstations	
						, char   *devicenom		
						, USHORT *deviceID		
						, USHORT carte			
						, USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_devices		pf_Get_devices;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! lecture du numero de version USB et de la vitesse moyenne de transfert pour un acces Ain()
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
GetInfo_Reseau(	  
					  USHORT *type				//!< USB...
					, USHORT *rev				//!< revision 
					, float  *bandepassante		//!< bande de passantetaux de transfert pour un transfert Ain()
					, ULONG  *ext				//!< extension future
					, USHORT carte				//!< Nom de la carte (cf. les \#define )
					, USHORT adresse			//!< FIXDOC Adresse de la carte
				);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_GetInfo_Reseau)(
							  USHORT *type				
							, USHORT *rev				
							, float  *bandepassante	
							, ULONG  *ext				
							, USHORT carte				
							, USHORT adresse			
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetInfo_Reseau		pf_GetInfo_Reseau;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END

//---------------------------------------------------------------------------------------
//! Initialisation d'un reseau
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Init_Reseau(
				  void  * _net_params	//!< Donnes spcifiant la facon dont le rseau doit tre configurer (dpendand du type de rseau)
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Init_Reseau)(
								void  * _net_params
							);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Init_Reseau		pf_Init_Reseau;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Stop_wdg(
			  USHORT ext		//!< Extension future
			, USHORT carte		//!< Nom de la carte (cf. les \#define )
            , USHORT adresse	//!< FIXDOC Adresse de la carte
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Stop_wdg)(
					  USHORT ext		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Stop_wdg		pf_Stop_wdg;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! lecture du numero de version du moniteur interne  la station  USB
/**
	Lecture d'un octet de 0  255
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Target_rev (
				  UCHAR  *rev		//!< numroe de version de 0  255
				, USHORT carte		//!< FIXDOC
				, USHORT adresse	//!< FIXDOC
			); 

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Target_rev)(
					  UCHAR  *rev		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Target_rev		pf_Target_rev;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Digitool_rev : lecture du numero de version de la DLL Digitool
/**
	Lecture d'un octet de 0  255
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Digitool_rev(
				UCHAR *rev //!< numroe de version de 0  255
			 );


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Digitool_rev)(
					UCHAR *rev
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Digitool_rev		pf_Digitool_rev;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END





//---------------------------------------------------------------------------------------
//! Rcupre l'ErrorCode d'un transfert Bulk
/** Permet de rceptionner le code de retour d'une fonction
d'ecriture sur un transfert bulk USB et elle assure ainsi la synchronisation des 
critures
\n Fonction active seulement sur les dernires version moniteur, test pour compatibilt de dll
-# usbnanolab/h : > version 4
-# usblab_v2 :    > version 10
-# usblabr  :    ok valide sur dpart
\note valide sur dout() cinit() cstop()  set_id() stop_wdg() aout() et fonctions flottantes
*/

//---------------------------------------------------------------------------------------
// fonctions a developper ......... incluses dans pcilab
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetDeviceNumber( 
					   ULONG *deviceNumber
					 , ULONG exts
					 , USHORT carte
				 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetDeviceNumber)(
						   ULONG *deviceNumber
						 , ULONG exts
						 , USHORT carte
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetDeviceNumber		pf_GetDeviceNumber;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//---------------------------------------------------------------------------------------
//! Retourne le nombre de carte du type demandese, dtectes dans le systmes
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(WORD)
Get_Nb_Cartes( 
					  WORD carte			//!< Identifiant de la carte (cf. le fichier DigiDefs_Cartes.def.h)
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(WORD)
(PASCAL *PROTO_Get_Nb_Cartes)(
							  WORD carte	
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_Nb_Cartes	pf_Get_Nb_Cartes;
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetPleineEchelleAD(
						  FLOAT* pleineEchelleAD
						, USHORT* mode
						, USHORT voie
						, ULONG exts
						, USHORT carte
						, USHORT adresse 
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetPleineEchelleAD)(
							  FLOAT* pleineEchelleAD
							, USHORT* mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetPleineEchelleAD		pf_GetPleineEchelleAD;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetPleineEchelleAD( 
						  FLOAT pleineEchelleAD
						, enum E_TYPE_POLARITE mode
						, USHORT voie
						, ULONG exts
						, USHORT carte
						, USHORT adresse 
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetPleineEchelleAD)(
							  FLOAT pleineEchelleAD
							, enum E_TYPE_POLARITE mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetPleineEchelleAD		pf_SetPleineEchelleAD;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetPleineEchelleDA( 
						  FLOAT* pleineEchelleDA
						, USHORT* mode
						, USHORT voie
						, ULONG exts
						, USHORT carte
						, USHORT adresse 
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetPleineEchelleDA)(
							  FLOAT* pleineEchelleDA
							, USHORT* mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetPleineEchelleDA		pf_GetPleineEchelleDA;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetPleineEchelleDA( 
						  FLOAT pleineEchelleDA
				   		, USHORT mode
						, USHORT voie
						, ULONG exts
						, USHORT carte
						, USHORT adresse
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetPleineEchelleDA)(
							  FLOAT pleineEchelleDA
				   			, USHORT mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetPleineEchelleDA		pf_SetPleineEchelleDA;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetTriggerAD( 
					USHORT voieAD		// numero de la voie utilisee pour le trigger
				  , FLOAT  triggerAD	// niveau de declenchement en tension 
				  , ULONG exts
				  , USHORT carte
				  , USHORT adresse
			  );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetTriggerAD)(
							USHORT voieAD	
						  , FLOAT  triggerAD	
						  , ULONG exts
						  , USHORT carte
						  , USHORT adresse
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetTriggerAD		pf_SetTriggerAD;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetTriggerAD( 
				    USHORT* pvoieAD     // numero de la voie utilisee pour le trigger
				  , FLOAT* ptriggerAD   // niveau de declenchement en tension 
				  , ULONG exts
				  , USHORT carte
				  , USHORT adresse 
			  );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetTriggerAD)(
							USHORT* pvoieAD     
						  , FLOAT* ptriggerAD   
						  , ULONG exts
						  , USHORT carte
						  , USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetTriggerAD		pf_GetTriggerAD;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
StopScan( 
				ULONG exts
			  , USHORT carte
			  , USHORT adresse
		  );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_StopScan)(
						ULONG exts
					  , USHORT carte
					  , USHORT adresse
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_StopScan		pf_StopScan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//##########################################################################
/*! @}*/ // Fin du groupe Operationnal_group
//##########################################################################











//##########################################################################
/**
	\addtogroup Event_group Gestion des venements gnrs par la Dll
	   Structures et Fonctions en rapport avec les venements gnrs par la Dll
	@{
*/
//##########################################################################
#pragma pack (2)  //alignement des 2 structures sur 2 octets copatible Digiview

//---------------------------------------------------------------------------------------
enum enum_digiSample_type
{
	SAMPLE_DIGITAL,
	SAMPLE_ANALOGIQUE,
};

//---------------------------------------------------------------------------------------
//! Donne d'un chantillon fait par une voie
typedef struct S_ECHANTILLON
{
	USHORT carte_type;							//!< Type de carte ayant gnr l'chantillon
	short  adresse;								//!< Numro de la carte du type #carte_type associe l'chantillon
	BYTE   num_voie;							//!< Numro de la voie qui a chantillonn
	enum   enum_digiSample_type sample_type;	//!< Type de l'chantillon
	DDWORD date;								//!< Date de rception de l'chantillonage

	//! Valeur de l'chantillon recu
	union UNION_VAL_SAMPLE
	{
		BYTE  digital;	//! Valide si #sample_type == SAMPLE_DIGITAL
		float analog;	//! Valide si #sample_type == SAMPLE_ANALOGIQUE
	};
	union UNION_VAL_SAMPLE val;
}
t_digiSample;

//---------------------------------------------------------------------------------------
// Types possible pour l'argument #ext d'un EventCallBack
union union_cb_ext
{
	BYTE b;
	int i;
	float f;
	t_digiSample* sample;
};

#pragma pack ()


//---------------------------------------------------------------------------------------
//! Signature des fonctions retour utiliss par les venements
//-------------------------------------------------------------------
typedef DIGI_CALLBACK_T(void) (DIGI_CALLBACK_U *t_EvtCB)( int evtID, USHORT carte, USHORT adresse, void* cb_Arg, union union_cb_ext* ext );



//! \cond NEVER
//-------------------------------------------------------------------
//! Enumration des evenement susceptibles d'tre utiliss par la Dll
//-------------------------------------------------------------------
enum ENUM_EVENT_TYPES
{
	#define X_DIGI_EVT( ID_EVT, NUM_EVT, STR_DESCRIPTIVE )	\
			ID_EVT = NUM_EVT,

	#include "DigiDefs_Events.def.h"
};
/*! \endcond */ // NEVER


//-------------------------------------------
//! Retourne la chaine de caractre decrivant l'evenement ayant l'id \a id_event
// NOTE : cette fonction est dfini dans DigiTool.cpp qu'il faudra inclure dans le projet si la fonction est utilise
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetEventString( int id_event );


//---------------------------------------------------------------------------------------
//! Assignation d'une fonction Retour  un vnement
/*
	IMPORTANT : les fonctions rappels assigns aux venements <em>ne doivent pas</em> appeler des fonctions de l'API.
	IMPORTANT : Il n'y a qu'un dclencheur appel par venement. Aussi un appel  EventCallBack__Set peut remplacer un dclencheur -et ses paramtres- mis en place prcdement.
			\n Une exception notable est lorsque evt_ID == USHORT_MAX : la fonction retour mis en place sera alors 
			la fonction retour par dfaut qui sera appel lorsqu'aucune autre fonction retour plus spcifique  l'venement
			n'est disponible.

	\param carte_type  : Identifiant du type de carte, dfinit dans <DigiDefs_Cartes.def.h>
	\param adresse     : le numro de la carte de type \a carte_type qui activera ce dclencheur, ou -1 pour toutes les cartes prsentes
	\param evt_ID      : l'ID de l'venement dclenchant parmi #ENUM_EVENT_TYPES 
						 , si == USHORT_MAX => la fonction retour \a f_CB devient la fonction par dfaut : sera appele quand aucune autre fonction retour n'est en enregistre
	\param f_CB        : la fonction retour appele quand l'venement dclencheur surviendra ou NULL pour annuler l'ventuelle fonction retour dj en place \see #t_EvtCB
	\param cb_Arg      : quand \a f_CB sera appele lors d'un vnement \
						, son paramtre ponyme aura cette valeur (Optionnel) \
						Si ce paramtres est un pointeur vers une zone malloc, la libration de la mmoire associe est \
						 la charge de l'appelant

	\return : ERR_DT_OK si tout est OK
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
EventCallBack__Set(	  
					  USHORT carte_type
					, short adresse
					, USHORT evtID
					, t_EvtCB f_CB
					, void* cb_Arg
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_EventCallBack__Set)(
							  USHORT carte_type
							, short adresse
							, USHORT evtID
							, t_EvtCB f_CB
							, void* cb_Arg
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_EventCallBack__Set		pf_EventCallBack__Set;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Rcupration des paramtre d'une fonction retour mis en place prcedement avec #EventCallBack__Set
/*
	\param carte_type  : Identifiant du type de carte
	\param adresse     : le numro de la carte qui doit activer la fonction retour recherche
	\param evt_ID      : l'ID de l'venement dclenchant de la fonction retour recherche, parmi #ENUM_EVENT_TYPES (si USHORT_MAX => c'est la foncion retour par dfaut qui est recherche)
	\param f_CB        : Paramtre rsultat. Au retour *f_CB vaudra la fonction retour recherche ou NULL si aucune
	\param cb_Arg      : Paramtre rsultat. Au retour *cb_Arg vaudra le paramtre associ  f_CB si elle existe ou NULL sinon

	\return : 0 si tout est OK
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
EventCallBack__Get(	 
				      USHORT carte_type
					, USHORT adresse
					, USHORT evtID
					, t_EvtCB* f_CB
					, void** cb_Arg
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_EventCallBack__Get)(
							  USHORT carte_type
							, USHORT adresse
							, USHORT evtID
							, t_EvtCB* f_CB
							, void** cb_Arg
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_EventCallBack__Get		pf_EventCallBack__Get;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//##########################################################################
/*! @}*/ // Fin de Event_Group
//##########################################################################




















//##########################################################################
/**
	\addtogroup Misc_group Fonctions atypique de la Dll
	   Fonctions atypique de la Dll, ie. qui n'ont pu tre incluse dans les prcdents groupes.
	@{
*/
//##########################################################################


//---------------------------------------------------------------------------------------
//! Spcifie la politique de verrouillage  utiliser pour les stations 
/**
	\param b_lock_temporaire : si Vrai les verrouillages dureront le temps de chaque appel  l'API, Sinon les verrouillages dureront le temps du processus.
	\return 0 si tout est OK
*/
//-------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Set_Verrouillage_Type( 
						bool b_lock_temporaire
					 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Set_Verrouillage_Type)( 
								bool b_lock_temporaire
							);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Set_Verrouillage_Type		pf_Set_Verrouillage_Type;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//		Noms, identifiants, et infos diverse des cartes Digi
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//|||||||||||||||||||||||||||||
// \cond NEVER
//|||||||||||||||||||||||||||||

//-------------------------------------------
//! Enumration des identifiants de cartes Digimtrie et de leur valeurs
// NOTE : gnre automatiquement par une X-macro utilisant le fichier  "DigiDefs_Cartes.def.h"
//-------------------------------------------------------------------
#define D_CARTE_DIGI( ID, NUM,	 S_NOM, S_DLL )	ID = NUM,

enum ENUM_DIGI_CARTES_IDS
{
	#include "DigiDefs_Cartes.def.h"
};

// Ces cartes ont leur ID qui est un doublon d'un de ceux de #ENUM_DIGI_CARTES_IDS
#define USB_LAB_LP	USB_LAB12
#define USB_LABR	USB2_LAB
#define PCI_OPTO16V PCI_OPTO18V


//|||||||||||||||||||||||||||||
/* \endcond */ // NEVER
//|||||||||||||||||||||||||||||

//-------------------------------------------
//! Retourne le nom de la carte correspondant
// NOTE : cette fonction est dfini dans DigiTool.cpp qu'il faudra inclure dans le projet si la fonction est utilise
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetCarte_Nom( int id_carte );


//-------------------------------------------
//! Retourne le nom de la Dll correspondante
/**    IMPORTANT : cette fonction est dfini dans DigiTool.cpp qui n'est pas compil avec la Dll.
	\n Il faudra l'inclure dans tout projet qui veut utiliser cette fonction.
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetCarte_Dll( int id_carte );


//-------------------------------------------
//! (R)Initialise les pointeurs de fonctions dfinis dans DigiTool.h
/**    
	 IMPORTANT : Pour pouvoir utiliser cette fonction, il faut inclure DigiTool.c dans votre Projet.
	 Dans DigiTool.h, un prototype et un pointeurs de fonction sont associs  chaque fonction exporte par la Dll.
	 Le nom des prototypes sont prfixs par "PROTO_" et le nom des pointeurs par "pf_".
	 Cette fonction initialise tout les pointeur de fonction ainsi dfinis  partir du HMODULE de la Dll pralablement charge.
	 Au retour de la fonction, les pointeurs de fonctions qui n'auront pas pu tre assigns vaudront NULL.

	\param h_loaded_Dll : Le HMODULE rendu par LoadLibrary()
	\param dll_path : Le chemin de la Dll donne  LoadLibrary()

	\return : TRUE si au moins un pointeur de fonction a pu tre initialis
*/
//-------------------------------------------------------------------
DTYPE_C(BOOL)
Digi_Init_Functions_Pointers( HMODULE h_loaded_Dll, P_STR dll_path );



//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//		Erreurs renvoy par les fonctions de la Dll
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//|||||||||||||||||||||||||||||
// \cond NEVER
//|||||||||||||||||||||||||||||

//-----------------------------------------------------------------------------------------------------
//! Enumration des identifiants d'erreurs et de leurs valeurs
// NOTE : gnre automatiquement par une X-macro utilisant le fichier  "DigiDefs_Errors.def.h"
//-------------------------------------------------------------------
#define D_DIGI_ERR( ID_ERR, NUM_ERR, STR_ERR )	\
	ID_ERR = NUM_ERR,

enum ENUM_DIGI_ERR
{
	#include "DigiDefs_Errors.def.h"
};

//|||||||||||||||||||||||||||||
/* \endcond */ // NEVER
//|||||||||||||||||||||||||||||

//-------------------------------------------
//! Retourne la chaine de caratre dcrivant l'erreur passe en paramtre
/**    IMPORTANT : cette fonction est dfini dans DigiTool.cpp qui n'est pas compil avec la Dll.
	\n Il faudra l'inclure dans tout projet qui veut utiliser cette fonction.
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetErrorString( int num_err );


//---------------------------------------------------------------------------------------
//! Permet de lire la dernire erreur d'une fonction 
/**
	\param erreur : OUT : vaudra la valeur de la dernire erreur rencontre par la Dll
	\param source : type d'erreur  demander  la station (seul 0 est valide pour l'instant)
	\param exts : inutilis
	\param carte : identifiant du type de carte
	\param adresse : numro de la carte de ce type  qui demand l'erreur
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Get_last_error(
					  short		*erreur		
					, WORD      source
					, ULONG     exts
					, WORD      carte
					, WORD      adresse
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_last_error)( 
							  short		*erreur 
							, WORD      source		
							, ULONG     exts		
							, WORD      carte 		
							, WORD      adresse		
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_last_error		pf_Get_last_error;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//##########################################################################
/*! @}*/ // Fin de Misc_Group
//##########################################################################






//##########################################################################
// Dfinitions diverses 
//##########################################################################

//||||||||||||||||||||||||||||||
/*! \endcond */ // EXLUSION_OFF
//||||||||||||||||||||||||||||||

//-----------------------------------------------
#ifndef USHORT_MAX
	#define USHORT_MAX    _UI16_MAX
#endif
#ifndef SHORT_MAX
	#define SHORT_MAX     _I16_MAX
#endif


//////////////////////////////////////////////////////////
//		Dfinition des bits du paramtre mode
///////////////////////////////////////////////
//Pour DINIT
#define DT_DINIT_IN		0x0000 //Entre
#define DT_DINIT_OUT	0x00FF //Sortie



//////////////////////////////////////////////////////////
//		Dfinition des bits a tester du paramtre mode
///////////////////////////////////////////////
//
//mode pour AINxxx et DINxxx
//

// definition des bits utilises pour masquer
#define bmBIT0    0x0001
#define bmBIT1    0x0002
#define bmBIT2    0x0004
#define bmBIT3    0x0008
#define bmBIT4    0x0010
#define bmBIT5    0x0020
#define bmBIT6    0x0040
#define bmBIT7    0x0080
#define bmBIT8    0x0100
#define bmBIT9    0x0200
#define bmBIT10   0x0400
#define bmBIT11   0x0800
#define bmBIT12   0x1000
#define bmBIT13   0x2000
#define bmBIT14   0x4000
#define bmBIT15   0x8000

// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions d'entre SCAN() exemple:AINSCAN et DINSCAN 

#define DT_AD_ENTREE	bmBIT15/* Niveau d'entre 0=monopolaire (0 a +V),
                               /* 1= bipolaire (-V  +V) */
#define DT_AD_VOIE		bmBIT14 /* Voies d'entrees 0=simple, 1=diffrentiel */
#define DT_AD_BUFF		bmBIT13  //0= buffer standard 1=buffer circulaire
#define DT_AD_CPT		bmBIT12  //0= Acq standard 1=derniere voie AD en compteur


#define DT_AD_TRGAH		bmBIT9	// 0=inactif, 1=trigger d'entre analogique front montant pour paquet d'acq
#define DT_AD_TRGAB		bmBIT8	// 0=inactif, 1=trigger d'entre analogique front descendant pour paquet d'acq

#define DT_AD_IRQ		bmBIT6 /* 0=inactif, 1=start des conversions sur top d'interruption */
#define DT_AD_EXT		bmBIT5 /* 0=inactif, 1=start des conversions sur signal externe*/
#define DT_AD_TIM		bmBIT4 /* 0=inactif, 1=frquence d'chantillonnage par generateur timer */
#define DT_AD_TRGIH		bmBIT3 /* 0=inactif, 1=trigger d'entre front montant pour paquet d'acquisition */
#define DT_AD_TRGIB		bmBIT2 /* 0=inactif, 1=trigger d'entre front descendant pour paquet d'acquisition*/
#define DT_AD_TRGOH		bmBIT1 /* 0=inactif, 1=trigger en sortie tat haut pour paquet d'acquisition */
#define DT_AD_TRGOB		bmBIT0 /* 0=inactif, 1=trigger en sortie tat bas pour paquet d'acquisition */
//Pour compatibilt digitool.h
#define DT_AD_MONO		DT_AD_ENTREE
#define DT_AD_SIMP		DT_AD_VOIE


// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions de sortie SCAN() exemple:AOUTSCAN et DOUTSCAN 
//
//
#define DT_DA_MONO		bmBIT15
#define DT_DA_SIMP		bmBIT14

#define DT_DA_TRGAH		bmBIT9	// 0=inactif, 1=trigger de sortie analogique front montant pour paquet d'acq
#define DT_DA_TRGAB		bmBIT8	// 0=inactif, 1=trigger de sortie analogique front descendant pour paquet d'acq

#define DT_DA_IRQ		bmBIT6
#define DT_DA_EXT		bmBIT5
#define DT_DA_TIM		bmBIT4
#define DT_DA_TRGIH		bmBIT3
#define DT_DA_TRGIB		bmBIT2
#define DT_DA_TRGOH		bmBIT1
#define DT_DA_TRGOB		bmBIT0


// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions generateur de signal GS_init() et Gs_stop()

#define DT_GS_ENTREE	bmBIT15/* Niveau d'entre 0=monopolaire (0 a +V), // N.U. usblabR
                               /* 1= bipolaire (0  +-V) */
#define DT_GS_WR    	bmBIT5    /* Ecriture freq et phase valide=1 ou devalide=0*/
#define DT_GS_REG_PHASE bmBIT4    /* Registre phase adder 0 ou 1 utilis */
#define DT_GS_REG_FREQ  bmBIT3    /* Registre phase 0 ou 1 utilis */
#define DT_GS_TRIANGLE	bmBIT2    /* Generateur de signal TRIANGLE */
#define DT_GS_CARRE	    bmBIT1    /* Generateur de signal carre */
#define DT_GS_SINUS	    bmBIT0    /* Generateur de signal sinus */

// dfinitions des paramtres commande et action utilises dans les fonctions Calibrage_An()

#define DT_CAL_CDE_DEF		0x0001    /* CDE: dfinir le calibrage charg par dfaut,sous tension ou reset*/
#define DT_CAL_CDE_CAL		0x0004    /* CDE: effectuer un calibrage utilisateur sur la voie_ref et voie_gnd*/
#define DT_CAL_ACT_USINE	0x0000    /* Action: Valeur defaut ou (calibrage usine)*/
#define DT_CAL_ACT_SAUV		0X0001    /* Action: calibrage utilisateur sans sauvegarde*/
#define DT_CAL_ACT_USER		0X0002    /* Action: Valeur defaut ou calibrage utilisateur*/

// dfinitions des commandes utilises dans les fonctions Read_Pot() Write_Pot() et Calibrage_An()
// Commandes masquee avec l'adresse ADDR 4 bits faibles ou bit A0 
// Exemple DT_POT_S_TO_M_CDE3 | 0x0003 => criture memoire EEMEM adresse 3

#define DT_POT_S_TO_M	0x0030	/* Commande 3: ecriture serial -> EEMEM(ADDR)*/
#define DT_POT_S_TO_R	0x00B0	/* Commande 11: ecriture serial -> RDAC(A0)*/
#define DT_POT_M_TO_S	0x0090	/* Commande 9: ecriture EEMEM(ADDR) -> serial avant lecture*/
#define DT_POT_R_TO_S	0x00A0	/* Commande 10: ecriture RDAC(A0) -> serial pour lecture*/
#define DT_POT_INC		0x00E0	/* Commande 14: ecriture increment +1 RDAC(A0)*/
#define DT_POT_DEC		0x0060	/* Commande 6: ecriture decrement -1 RDAC(A0)*/
#define DT_POT_RESET	0x0080	/* Commande 8: RESET  EEMM0/1 dans RDAC0/1*/
#define DT_POT_SAVE		0x0020	/* Commande 2 : SAVE position RDAC(A0) -> EEMEM(A0)*/
#define DT_POT_NOP		0x0000	/* Commande 0: NOP  + minimum power,Utilise pour lecture aprs CDE 9 et 10*/



//////////////////////////////////////////////////////////
//		Dfinition des bits du paramtre no_composant
///////////////////////////////////////////////
// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions d'entre et sortie TOR SCAN() exemple:DOUTSCAN et DINSCAN 

#define DT_TOR_TIM	    bmBIT4 /* 0=inactif, 1=frquence d'chantillonnage par generateur timer interne*/
#define DT_TOR_TRGIH	bmBIT3 /* 0=inactif, 1=trigger d'entre front montant pour paquet d'acquisition */
#define DT_TOR_TRGIB    bmBIT2 /* 0=inactif, 1=trigger d'entre front descendant pour paquet d'acquisition*/
#define DT_TOR_TRGOH	bmBIT1 /* 0=inactif, 1=trigger en sortie tat haut pour paquet d'acquisition */
#define DT_TOE_TRGOB	bmBIT0 /* 0=inactif, 1=trigger en sortie tat bas pour paquet d'acquisition */

//Pour les fonctions gnrateur Ginit, Gstart, Gstop
#define DT_TIM_G32B		0X0008	// masque gnrateur 32 bits valid
#define DT_TIM_G16B		0X0000	// masque gnrateur 16 bits valid
#define DT_TIM_MOD0		0X0000	// mode 0 slectionn top type interruption
#define DT_TIM_MOD2		0X0002	// mode 2 slectionn rapport cycique 1/freq
#define DT_TIM_MOD3		0X0003	// mode 3 slectionn rapport cycique 1/2

//
//mode pour  fonctions timer generateur Gxxxx
//
#define DT_TIM_G32B		0X0008	// masque gnrateur 32 bits valid
#define DT_TIM_G16B		0X0000	// masque gnrateur 16 bits valid
#define DT_TIM_MOD0		0X0000	// mode 0 slect top type interruption
#define DT_TIM_MOD1		0X0000	// mode 1 non disponible
#define DT_TIM_MOD2		0X0002	// mode 2 slect rapport cycique 1/freq
#define DT_TIM_MOD3		0X0003	// mode 3 slect rapport cycique 1/2
#define DT_TIM_MOD		bmBIT1 | bmBIT1 	// masque parametre mode  
//
// no_composant pour fonctions timer generateur Gxxxx
//
#define DT_TIM_CPT0B	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1B	0X0100	// 16 bits bas d'un timer
#define DT_TIM_CPT2B	0X0200	// 3 compteurs internes dfinis

#define DT_TIM_CPT0H	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1H	0X1000	// 16 bits haut d'un timer
#define DT_TIM_CPT2H	0X2000	// 3 compteurs internes dfinis

#define DT_TIM_TIM0B	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1B	0X0001	// au compteur 16 bits bas utilis
#define DT_TIM_TIM2B	0X0002	// 8 timers par carte dfinis
#define DT_TIM_TIM3B	0X0003
#define DT_TIM_TIM4B	0X0004
#define DT_TIM_TIM5B	0X0005
#define DT_TIM_TIM6B	 0X0006
#define DT_TIM_TIM7B	0X0007

#define DT_TIM_TIM0H	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1H	0X0010	// au compteur 16 bits haut utilis
#define DT_TIM_TIM2H	0X0020	// 8 timers par carte dfinis
#define DT_TIM_TIM3H	0X0030
#define DT_TIM_TIM4H	0X0040
#define DT_TIM_TIM5H	0X0050
#define DT_TIM_TIM6H	0X0060
#define DT_TIM_TIM7H	0X0070

//Pour Gxxxx
#define DT_TIM_CPT0B	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1B	0X0100	// 16 bits bas d'un timer
#define DT_TIM_CPT2B	0X0200	// 3 compteurs internes dfinis

#define DT_TIM_CPT0H	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1H	0X1000	// 16 bits haut d'un timer
#define DT_TIM_CPT2H	0X2000	// 3 compteurs internes dfinis

#define DT_TIM_TIM0B	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1B	0X0001	// au compteur 16 bits bas utilis
#define DT_TIM_TIM2B	0X0002	// 8 timers par carte dfinis
#define DT_TIM_TIM3B	0X0003
#define DT_TIM_TIM4B	0X0004
#define DT_TIM_TIM5B	0X0005
#define DT_TIM_TIM6B	0X0006
#define DT_TIM_TIM7B	0X0007

#define DT_TIM_TIM0H	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1H	0X0010	// au compteur 16 bits haut utilis
#define DT_TIM_TIM2H	0X0020	// 8 timers par carte dfinis
#define DT_TIM_TIM3H	0X0030
#define DT_TIM_TIM4H	0X0040
#define DT_TIM_TIM5H	0X0050
#define DT_TIM_TIM6H	0X0060
#define DT_TIM_TIM7H	0X0070

/* dfinition des ports logiques */
#define PORTA     0
#define PORTB     1
#define PORTC     2

///////////////////////////////////////////////////
//		Paramtre Status (pour les ITs)
/////////////////////////////////////////
#define DT_AD_INT_ACQUISITION_NON_COMMENCEE	0
#define DT_AD_INT_ACQUISITION_EN_COURS		1
#define DT_AD_INT_ACQUISITION_FINIE			2




//|||||||||||||||||||||||||||||
/*! \endcond */ // EXLUSION_OFF
//|||||||||||||||||||||||||||||


//--------------------------------------------------------------------------
// Pour Compatibilit avec le DOS
#define inportb inp
#define outportb outp
#define outportw outpw
#define inportw inpw
#define inport inp
#define outport outp


//--------------------------------------------------------------------------
// FIXME : qu'est ce ?
#define DT_MESS_TRIGGER_ON    1000    /* message trigger  ON	 	*/
#define DT_MESS_TRIGGER_OFF   1001    /* message trigger  OFF	 	*/


//##########################################################################
/*! @}*/ // Fin de API_group
//##########################################################################


//+++++++++++++++++++++++++++++++++++++++++++++++
#endif // DIGITOOL_H
